@@ -36,6 +36,12 @@ private Q_SLOTS:
     void assignmentTest();
     void serializeTest();
     void formatTest();
+    void shouldExportVcard4();
+    void shouldExportVcard3();
+    void shouldParseAddressVCard3();
+    void shouldParseAddressVCard4();
+    void shouldExportVCard4WithGeoPosition();
+    void shouldParseAddressVCard4WithGeoPosition();
 };
 
 #endif
